#!/bin/bash
# ------------------------------------------------------------------------------
# (C) Copyright 1995 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its
# affiliates and licensors (“Micro Focus”) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial
# errors or omissions contained herein. The information contained herein
# is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains
# confidential information and a valid license is required for possession,
# use or copying. If this work is provided to the U.S. Government,
# consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items
# are licensed to the U.S. Government under vendor's standard commercial
# license.
# ------------------------------------------------------------------------------
#
# script to setup postgres
# this script has to be executed as part of postgres post-install

if [ -d ~postgres/data ]
then
	systemctl stop postgresql
	rm -r ~postgres/data
fi

su - postgres -c "initdb -U postgres ~postgres/data"
systemctl start postgresql
systemctl enable postgresql

# generate self signed certificate
mkdir /tmp/umcDb
/usr/share/sfcb/genSslCert.sh /tmp/umcDb
cp /tmp/umcDb/server.pem ~postgres/data/servercert.pem
cp /tmp/umcDb/file.pem ~postgres/data/serverkey.pem

chown postgres:postgres ~postgres/data/servercert.pem
chown postgres:postgres ~postgres/data/serverkey.pem
chmod 600 ~postgres/data/servercert.pem
chmod 600 ~postgres/data/serverkey.pem

rm -rf /tmp/umcDb

echo "listen_addresses = '*'" >> ~postgres/data/postgresql.conf
echo "port = $1" >> ~postgres/data/postgresql.conf
echo "ssl = on" >> ~postgres/data/postgresql.conf
echo "ssl_cert_file = 'servercert.pem'" >> ~postgres/data/postgresql.conf
echo "ssl_key_file = 'serverkey.pem'" >> ~postgres/data/postgresql.conf
echo "ssl_ciphers = 'HIGH:MEDIUM:+3DES:!aNULL'" >> ~postgres/data/postgresql.conf
echo "ssl_min_protocol_version = 'TLSv1.2'" >> ~postgres/data/postgresql.conf
echo "host    all             all             0.0.0.0/0               scram-sha-256" >> ~postgres/data/pg_hba.conf
systemctl restart postgresql.service
